While Android 9 has introduced new restrictions to access these APIs, the collection of Wifi data to profile users is
a known practice popular among Ads SDK and third-party analytics libraries.

Collection of these data is in most cases not required and should either disabled, or 3rd party libraries accessing it
should be replaced with privacy-aware libraries.